@@ -5,7 +5,7 @@
 ;; Author: Jimmy Aguilar Mena
 ;; URL: https://github.com/Ergus/gtags-mode
 ;; Keywords: xref, project, imenu, gtags, global
-;; Version: 1.8
+;; Version: 1.8.1
 ;; Package-Requires: ((emacs "28"))
 
 ;; This program is free software: you can redistribute it and/or modify
@@ -75,7 +75,11 @@
 (defcustom gtags-mode-features '(project xref completion imenu hooks)
   "The list of features enabled in gtags-mode.
 This variable must be set before enabling gtags-mode"
-  :type '(repeat symbol)
+  :type '(set (const project)
+              (const xref)
+              (const completion)
+              (const imenu)
+              (const hooks))
   :risky t)
 
 (defcustom gtags-mode-verbose-level 2
@@ -195,6 +199,29 @@ On success return a list of strings or nil if any error occurred."
     (gtags-mode--message 1 "Can't start sync %s subprocess" cmd)
     nil))
 
+
+
+(defsubst gtags-mode--get-root (dir)
+  "Get the top dbpath given DIR.
+Includes the remote prefix concatenation when needed."
+  ;; The first check is an Heuristic to create new plists only when
+  ;; visiting real files This optimizes when there is not tags file to
+  ;; avoid calling the external process repeatedly i.e in magit
+  ;; buffers that are regenerated every time and forgets the local
+  ;; variables
+  (when-let* (((and gtags-mode--global buffer-file-name))
+	      ;; Then suppress any warning when searching the root
+	      ;; because `global' returns an error value when there is
+	      ;; not dbpath found.
+	      (gtags-mode-verbose-level 0)
+	      (default-directory dir)
+	      ;; The check id independent of the concat because when
+	      ;; empty (no root) on remote systems, the concat will
+	      ;; returns always a non nil value.
+	      (root (car (gtags-mode--exec-sync "--print-dbpath"))))
+    (concat (file-remote-p dir)              ;; add remote prefix if remote
+	    (file-name-as-directory root)))) ;; add a / at the end if missing
+
 ;; Utilities functions (a bit less low level) ========================
 (defun gtags-mode--get-plist (dir)
   "Return the plist for DIR from `gtags-mode--alist'."
@@ -204,15 +231,7 @@ On success return a list of strings or nil if any error occurred."
 
 (defun gtags-mode--create-plist (dir)
   "Return dbpath for DIR or nil if none."
-  ;; Heuristic to create new plists only when visiting real files
-  ;; This optimizes when there is not tags file to avoid calling
-  ;; the external process repeatedly i.e in magit buffers that are
-  ;; regenerated every time and forgets the local variables
-  (when-let* (((and gtags-mode--global buffer-file-name))
-	      (default-directory dir)
-	      (root (car (gtags-mode--exec-sync "--print-dbpath"))))
-    (setq root (concat (file-remote-p default-directory) ;; add remote prefix if remote
-		       (file-name-as-directory root)))   ;; add a / at the end is missing
+  (when-let ((root (gtags-mode--get-root dir)))
     (gtags-mode--message 2 "Gtags file in %s applies to default-directory: %s" root dir)
     (or (gtags-mode--get-plist root)   ;; already exist
 	(car (push `(:gtagsroot ,root :cache nil) gtags-mode--alist)))))
@@ -238,7 +257,8 @@ completions usually from the cache when possible."
   (cond ;; TODO: use with-memoization in the future it will be on emacs 29.1
    ((not (gtags-mode--local-plist default-directory))
     (error "Calling `gtags-mode--list-completions' with no gtags-mode--plist"))
-   ((and (stringp prefix) (not (string-blank-p prefix))
+   ((and (stringp prefix)
+	 (not (string-match-p "\\`[ \t\n\r-]*\\'" prefix)) ;; not match empty or only -
 	 (gtags-mode--exec-sync "--ignore-case" "--completion" prefix)))
    ((plist-get gtags-mode--plist :cache))
    (t (plist-put gtags-mode--plist :cache (gtags-mode--exec-sync "--completion"))
